==> haskell-configurator-0.3.0.0-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-1pyU9QYl2Wz1xrdwiJo55d
key: configurator-0.3.0.0-1pyU9QYl2Wz1xrdwiJo55d
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
abi: 3700965654076ae37b5bbb5e6a62d6d9
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-1pyU9QYl2Wz1xrdwiJo55d
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    bytestring-0.10.8.2 directory-1.3.3.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-44Mh8LyvttT1hQwsIXxhZY
key: configurator-0.3.0.0-44Mh8LyvttT1hQwsIXxhZY
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
abi: aeb4d68c74d345ca287c0d9442361e6e
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-44Mh8LyvttT1hQwsIXxhZY
depends:
    attoparsec-0.13.2.2-EiCOeTjO227AS8aig3dZEf base-4.12.0.0
    bytestring-0.10.8.2 directory-1.3.3.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
